@@ -8,7 +8,7 @@
     unsafe_code,
     unused_import_braces,
     unused_qualifications,
-    // warnings
+    warnings
 )]
 #![cfg_attr(not(feature = "std"), no_std)]
 
@@ -19,10 +19,11 @@ extern crate core;
 #[macro_use]
 extern crate alloc;
 
+use cfg_if::cfg_if;
+
 pub use change::*;
 pub use channel::*;
 pub use contact::*;
-pub use credential::*;
 pub use entity::*;
 pub use entity_builder::*;
 pub use error::*;
@@ -31,8 +32,7 @@ pub use key_attributes::*;
 pub use lease::*;
 use ockam_channel::SecureChannelVault;
 use ockam_core::compat::{collections::HashMap, string::String, vec::Vec};
-use ockam_core::{Address, Decodable, Encodable, Message, Result};
-use ockam_node::{block_future, Context};
+use ockam_core::{Decodable, Encodable, Result};
 use ockam_vault::{Hasher, KeyIdVault, SecretVault, Signer, Verifier};
 pub use profile::*;
 pub use profile_state::*;
@@ -41,73 +41,11 @@ pub use worker::*;
 
 use crate::EntityError;
 
-pub struct Handle {
-    ctx: Context,
-    address: Address,
-}
-
-impl Clone for Handle {
-    fn clone(&self) -> Self {
-        block_future(&self.ctx.runtime(), async move {
-            Handle {
-                ctx: self
-                    .ctx
-                    .new_context(Address::random(0))
-                    .await
-                    .expect("new_context failed"),
-                address: self.address.clone(),
-            }
-        })
-    }
-}
-
-impl Handle {
-    pub fn new(ctx: Context, address: Address) -> Self {
-        Handle { ctx, address }
-    }
-
-    pub async fn async_cast<M: Message + Send + 'static>(&self, msg: M) -> Result<()> {
-        self.ctx.send(self.address.clone(), msg).await
-    }
-
-    pub fn cast<M: Message + Send + 'static>(&self, msg: M) -> Result<()> {
-        block_future(
-            &self.ctx.runtime(),
-            async move { self.async_cast(msg).await },
-        )
-    }
-
-    pub async fn async_call<I: Message + Send + 'static, O: Message + Send + 'static>(
-        &self,
-        msg: I,
-    ) -> Result<O> {
-        let mut ctx = self
-            .ctx
-            .new_context(Address::random(0))
-            .await
-            .expect("new_context failed");
-        ctx.send(self.address.clone(), msg).await?;
-        let msg = ctx.receive::<O>().await?;
-        Ok(msg.take().body())
-    }
-
-    pub fn call<I: Message + Send + 'static, O: Message + Send + 'static>(
-        &self,
-        msg: I,
-    ) -> Result<O> {
-        block_future(
-            &self.ctx.runtime(),
-            async move { self.async_call(msg).await },
-        )
-    }
-}
-
 mod authentication;
 mod change;
 pub mod change_history;
 mod channel;
 mod contact;
-mod credential;
 mod entity;
 mod entity_builder;
 mod error;
@@ -120,6 +58,13 @@ mod proof;
 mod traits;
 mod worker;
 
+cfg_if! {
+    if #[cfg(feature = "credentials")] {
+        mod credential;
+        pub use credential::*;
+    }
+}
+
 /// Traits required for a Vault implementation suitable for use in a Profile
 pub trait ProfileVault:
     SecretVault + SecureChannelVault + KeyIdVault + Hasher + Signer + Verifier + Clone + Send + 'static
@@ -144,7 +89,9 @@ pub type ProfileEventAttributes = HashMap<String, String>;
 /// Contacts Database
 pub type Contacts = HashMap<ProfileIdentifier, Contact>;
 
+#[cfg(feature = "credentials")]
 pub use signature_bbs_plus::{PublicKey as BbsPublicKey, SecretKey as BbsSecretKey};
+#[cfg(feature = "credentials")]
 pub use signature_bls::{PublicKey as BlsPublicKey, SecretKey as BlsSecretKey};
 
 pub struct ProfileSerializationUtil;
