@@ -3,9 +3,11 @@ mod entity_worker;
 mod request;
 mod response;
 mod rotate_key;
+mod trust_policy_worker;
 
 pub use create_key::*;
 pub use entity_worker::*;
 pub use request::*;
 pub use response::*;
 pub use rotate_key::*;
+pub use trust_policy_worker::*;
