@@ -1,14 +1,14 @@
 use crate::{
-    CredentialHolder, CredentialIssuer, CredentialProof, CredentialPublicKey,
-    CredentialRequestFragment, CredentialVerifier, EntityError::IdentityApiFailed, Handle,
-    Identity, IdentityRequest, IdentityRequest::*, IdentityResponse as Res, MaybeContact, Profile,
-    ProfileIdentifier, ProfileState, SecureChannelTrait, TrustPolicyImpl,
+    EntityError::IdentityApiFailed, Identity, IdentityRequest, IdentityRequest::*,
+    IdentityResponse as Res, MaybeContact, Profile, ProfileIdentifier, ProfileState,
+    SecureChannelTrait, TrustPolicyImpl,
 };
-use async_trait::async_trait;
 use core::result::Result::Ok;
-use ockam_core::compat::{boxed::Box, collections::HashMap};
-use ockam_core::{Address, Result, Routed, Worker};
-use ockam_node::Context;
+use ockam_core::{
+    async_trait::async_trait, compat::boxed::Box, compat::collections::HashMap, Address, Result,
+    Routed, Worker,
+};
+use ockam_node::{Context, Handle};
 use ockam_vault_sync_core::VaultSync;
 
 #[cfg(feature = "lease_proto_json")]
@@ -207,159 +207,6 @@ impl Worker for EntityWorker {
 
                 Ok(())
             }
-            GetSigningKey(profile_id) => {
-                if let Ok(signing_key) = self.profile(&profile_id).get_signing_key() {
-                    ctx.send(reply, Res::GetSigningKey(signing_key)).await
-                } else {
-                    err()
-                }
-            }
-            GetIssuerPublicKey(profile_id) => {
-                if let Ok(public_key) = self.profile(&profile_id).get_signing_public_key() {
-                    ctx.send(
-                        reply,
-                        Res::GetIssuerPublicKey(CredentialPublicKey(public_key)),
-                    )
-                    .await
-                } else {
-                    err()
-                }
-            }
-            CreateOffer(profile_id, schema) => {
-                if let Ok(offer) = self.profile(&profile_id).create_offer(&schema) {
-                    ctx.send(reply, Res::CreateOffer(offer)).await
-                } else {
-                    err()
-                }
-            }
-            CreateProofOfPossession(profile_id) => {
-                if let Ok(pop) = self.profile(&profile_id).create_proof_of_possession() {
-                    ctx.send(reply, Res::CreateProofOfPossession(CredentialProof(pop)))
-                        .await
-                } else {
-                    err()
-                }
-            }
-            SignCredential(profile_id, schema, attributes) => {
-                if let Ok(credential) = self
-                    .profile(&profile_id)
-                    .sign_credential(&schema, attributes.as_slice())
-                {
-                    ctx.send(reply, Res::SignCredential(credential)).await
-                } else {
-                    err()
-                }
-            }
-            SignCredentialRequest(profile_id, request, schema, attributes, offer_id) => {
-                if let Ok(frag) = self.profile(&profile_id).sign_credential_request(
-                    &request,
-                    &schema,
-                    attributes.as_slice(),
-                    offer_id,
-                ) {
-                    ctx.send(reply, Res::SignCredentialRequest(frag)).await
-                } else {
-                    err()
-                }
-            }
-            AcceptCredentialOffer(profile_id, offer, signing_public_key) => {
-                if let Ok(cred_and_fragment) = self
-                    .profile(&profile_id)
-                    .accept_credential_offer(&offer, signing_public_key.0)
-                {
-                    ctx.send(
-                        reply,
-                        Res::AcceptCredentialOffer(CredentialRequestFragment(
-                            cred_and_fragment.0,
-                            cred_and_fragment.1,
-                        )),
-                    )
-                    .await
-                } else {
-                    err()
-                }
-            }
-            CombineCredentialFragments(profile_id, frag1, frag2) => {
-                if let Ok(credential) = self
-                    .profile(&profile_id)
-                    .combine_credential_fragments(frag1, frag2)
-                {
-                    ctx.send(reply, Res::CombineCredentialFragments(credential))
-                        .await
-                } else {
-                    err()
-                }
-            }
-            IsValidCredential(profile_id, credential, issuer_public_key) => {
-                if let Ok(valid) = self
-                    .profile(&profile_id)
-                    .is_valid_credential(&credential, issuer_public_key.0)
-                {
-                    ctx.send(reply, Res::IsValidCredential(valid)).await
-                } else {
-                    err()
-                }
-            }
-            PresentCredential(profile_id, credential, manifest, request_id) => {
-                if let Ok(presentations) = self.profile(&profile_id).present_credentials(
-                    &[credential],
-                    &[manifest],
-                    request_id,
-                ) {
-                    let presentation = presentations
-                        .first()
-                        .expect("expected at least one presentation");
-
-                    ctx.send(reply, Res::PresentCredential(presentation.clone()))
-                        .await
-                } else {
-                    err()
-                }
-            }
-            CreateProofRequestId(profile_id) => {
-                if let Ok(request_id) = self.profile(&profile_id).create_proof_request_id() {
-                    ctx.send(reply, Res::CreateProofRequestId(request_id)).await
-                } else {
-                    err()
-                }
-            }
-            VerifyProofOfPossession(profile_id, signing_public_key, proof_of_possession) => {
-                if let Ok(valid) = self
-                    .profile(&profile_id)
-                    .verify_proof_of_possession(signing_public_key.0, proof_of_possession.0)
-                {
-                    ctx.send(reply, Res::VerifyProofOfPossession(valid)).await
-                } else {
-                    err()
-                }
-            }
-            VerifyCredentialPresentation(profile_id, presentation, manifest, request_id) => {
-                if let Ok(valid) = self.profile(&profile_id).verify_credential_presentations(
-                    &[presentation],
-                    &[manifest],
-                    request_id,
-                ) {
-                    ctx.send(reply, Res::VerifyCredentialPresentation(valid))
-                        .await
-                } else {
-                    err()
-                }
-            }
-            AddCredential(profile_id, credential) => {
-                if let Ok(()) = self.profile(&profile_id).add_credential(credential) {
-                    ctx.send(reply, Res::AddCredential).await
-                } else {
-                    err()
-                }
-            }
-            GetCredential(profile_id, credential) => {
-                if let Ok(c) = self.profile(&profile_id).get_credential(&credential) {
-                    ctx.send(reply, Res::GetCredential(c)).await
-                } else {
-                    err()
-                }
-            }
-
             GetLease(lease_manager_route, profile_id, org_id, bucket, ttl) => {
                 let profile = self.profile(&profile_id);
                 if let Ok(lease) =
@@ -389,10 +236,235 @@ impl Worker for EntityWorker {
                     panic!("No lease protocol implementations available")
                 }
             }
-
             RevokeLease(lease_manager_route, profile_id, lease) => self
                 .profile(&profile_id)
                 .revoke_lease(&lease_manager_route, lease),
+            #[cfg(feature = "credentials")]
+            CredentialRequest(req) => {
+                use crate::IdentityCredentialRequest::*;
+                use crate::IdentityCredentialResponse as CredRes;
+                use crate::{
+                    CredentialHolder, CredentialIssuer, CredentialProof, CredentialPublicKey,
+                    CredentialRequestFragment, CredentialVerifier,
+                };
+                match req {
+                    GetSigningKey(profile_id) => {
+                        if let Ok(signing_key) = self.profile(&profile_id).get_signing_key() {
+                            ctx.send(
+                                reply,
+                                Res::CredentialResponse(CredRes::GetSigningKey(signing_key)),
+                            )
+                            .await
+                        } else {
+                            err()
+                        }
+                    }
+                    GetIssuerPublicKey(profile_id) => {
+                        if let Ok(public_key) = self.profile(&profile_id).get_signing_public_key() {
+                            ctx.send(
+                                reply,
+                                Res::CredentialResponse(CredRes::GetIssuerPublicKey(
+                                    CredentialPublicKey(public_key),
+                                )),
+                            )
+                            .await
+                        } else {
+                            err()
+                        }
+                    }
+                    CreateOffer(profile_id, schema) => {
+                        if let Ok(offer) = self.profile(&profile_id).create_offer(&schema) {
+                            ctx.send(reply, Res::CredentialResponse(CredRes::CreateOffer(offer)))
+                                .await
+                        } else {
+                            err()
+                        }
+                    }
+                    CreateProofOfPossession(profile_id) => {
+                        if let Ok(pop) = self.profile(&profile_id).create_proof_of_possession() {
+                            ctx.send(
+                                reply,
+                                Res::CredentialResponse(CredRes::CreateProofOfPossession(
+                                    CredentialProof(pop),
+                                )),
+                            )
+                            .await
+                        } else {
+                            err()
+                        }
+                    }
+                    SignCredential(profile_id, schema, attributes) => {
+                        if let Ok(credential) = self
+                            .profile(&profile_id)
+                            .sign_credential(&schema, attributes.as_slice())
+                        {
+                            ctx.send(
+                                reply,
+                                Res::CredentialResponse(CredRes::SignCredential(credential)),
+                            )
+                            .await
+                        } else {
+                            err()
+                        }
+                    }
+                    SignCredentialRequest(profile_id, request, schema, attributes, offer_id) => {
+                        if let Ok(frag) = self.profile(&profile_id).sign_credential_request(
+                            &request,
+                            &schema,
+                            attributes.as_slice(),
+                            offer_id,
+                        ) {
+                            ctx.send(
+                                reply,
+                                Res::CredentialResponse(CredRes::SignCredentialRequest(frag)),
+                            )
+                            .await
+                        } else {
+                            err()
+                        }
+                    }
+                    AcceptCredentialOffer(profile_id, offer, signing_public_key) => {
+                        if let Ok(cred_and_fragment) = self
+                            .profile(&profile_id)
+                            .accept_credential_offer(&offer, signing_public_key.0)
+                        {
+                            ctx.send(
+                                reply,
+                                Res::CredentialResponse(CredRes::AcceptCredentialOffer(
+                                    CredentialRequestFragment(
+                                        cred_and_fragment.0,
+                                        cred_and_fragment.1,
+                                    ),
+                                )),
+                            )
+                            .await
+                        } else {
+                            err()
+                        }
+                    }
+                    CombineCredentialFragments(profile_id, frag1, frag2) => {
+                        if let Ok(credential) = self
+                            .profile(&profile_id)
+                            .combine_credential_fragments(frag1, frag2)
+                        {
+                            ctx.send(
+                                reply,
+                                Res::CredentialResponse(CredRes::CombineCredentialFragments(
+                                    credential,
+                                )),
+                            )
+                            .await
+                        } else {
+                            err()
+                        }
+                    }
+                    IsValidCredential(profile_id, credential, issuer_public_key) => {
+                        if let Ok(valid) = self
+                            .profile(&profile_id)
+                            .is_valid_credential(&credential, issuer_public_key.0)
+                        {
+                            ctx.send(
+                                reply,
+                                Res::CredentialResponse(CredRes::IsValidCredential(valid)),
+                            )
+                            .await
+                        } else {
+                            err()
+                        }
+                    }
+                    PresentCredential(profile_id, credential, manifest, request_id) => {
+                        if let Ok(presentations) = self.profile(&profile_id).present_credentials(
+                            &[credential],
+                            &[manifest],
+                            request_id,
+                        ) {
+                            let presentation = presentations
+                                .first()
+                                .expect("expected at least one presentation");
+
+                            ctx.send(
+                                reply,
+                                Res::CredentialResponse(CredRes::PresentCredential(
+                                    presentation.clone(),
+                                )),
+                            )
+                            .await
+                        } else {
+                            err()
+                        }
+                    }
+                    CreateProofRequestId(profile_id) => {
+                        if let Ok(request_id) = self.profile(&profile_id).create_proof_request_id()
+                        {
+                            ctx.send(
+                                reply,
+                                Res::CredentialResponse(CredRes::CreateProofRequestId(request_id)),
+                            )
+                            .await
+                        } else {
+                            err()
+                        }
+                    }
+                    VerifyProofOfPossession(
+                        profile_id,
+                        signing_public_key,
+                        proof_of_possession,
+                    ) => {
+                        if let Ok(valid) = self
+                            .profile(&profile_id)
+                            .verify_proof_of_possession(signing_public_key.0, proof_of_possession.0)
+                        {
+                            ctx.send(
+                                reply,
+                                Res::CredentialResponse(CredRes::VerifyProofOfPossession(valid)),
+                            )
+                            .await
+                        } else {
+                            err()
+                        }
+                    }
+                    VerifyCredentialPresentation(
+                        profile_id,
+                        presentation,
+                        manifest,
+                        request_id,
+                    ) => {
+                        if let Ok(valid) =
+                            self.profile(&profile_id).verify_credential_presentations(
+                                &[presentation],
+                                &[manifest],
+                                request_id,
+                            )
+                        {
+                            ctx.send(
+                                reply,
+                                Res::CredentialResponse(CredRes::VerifyCredentialPresentation(
+                                    valid,
+                                )),
+                            )
+                            .await
+                        } else {
+                            err()
+                        }
+                    }
+                    AddCredential(profile_id, credential) => {
+                        if let Ok(()) = self.profile(&profile_id).add_credential(credential) {
+                            ctx.send(reply, Res::CredentialResponse(CredRes::AddCredential))
+                                .await
+                        } else {
+                            err()
+                        }
+                    }
+                    GetCredential(profile_id, credential) => {
+                        if let Ok(c) = self.profile(&profile_id).get_credential(&credential) {
+                            ctx.send(reply, Res::CredentialResponse(CredRes::GetCredential(c)))
+                                .await
+                        } else {
+                            err()
+                        }
+                    }
+                }
+            }
         }
     }
 }
