@@ -1,8 +1,7 @@
-use crate::{Handle, SecureChannelTrustInfo, TrustPolicy};
-use async_trait::async_trait;
+use crate::{SecureChannelTrustInfo, TrustPolicy};
 use ockam_core::compat::boxed::Box;
-use ockam_core::{Address, Result, Routed, Worker};
-use ockam_node::Context;
+use ockam_core::{async_trait::async_trait, Address, Result, Routed, Worker};
+use ockam_node::{Context, Handle};
 use serde::{Deserialize, Serialize};
 
 #[derive(Clone)]
